==> LL_utils-4.1.1.4-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/pull_down_tab_panel_classes.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)22 1.10 src/ll/config_editor/cgi-bin/pull_down_tab_panel_classes.pl, ll.config, ll_rrur2, rrur21042a 1/2/10 03:57:37\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($mysql_host, $mysql_user, $mysql_pass, $mysql_db) = get_db_info(0);

my @normal_tables_by_classID = @{LLUtil::ALL_TABLES->{"tab_panel_classes"}->[0]};
my @editable_tables_by_classID = @{LLUtil::ALL_TABLES->{"tab_panel_classes"}->[1]};
my @multi_select_tables_by_classID = @{LLUtil::ALL_TABLES->{"tab_panel_classes"}->[2]};

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;
if(/id=(\d+)&name=(.*)&cluster=(\d+)/)
{
	my $json_str_0 = "Content-type: text/html\n\n";
	
	my $dbh = DBI->connect("DBI:mysql:database=$mysql_db;host=$mysql_host",$mysql_user,$mysql_pass);
        if(!defined($dbh))
	{
		my $json_str_err = $json_str_0."Error:".DBI->errstr;
		print $json_str_err;
		exit 1;
	}
	
	my $classID = $1;
	my $option_name = $2;
	my $cluster_id = $3;
	
	my $sql_str;
	my $sth;

	my $json_str = $json_str_0."[";

	# Get default class id
	my $default_class_id = undef;
	if($classID != 0)
	{
		$default_class_id = get_default_id_by_primary_key($dbh,"classID","clusterID","TLLS_CFGClass","name",$classID);
	}
	else
	{
		$default_class_id = get_default_id($dbh,"classID","name","TLLS_CFGClass",$cluster_id);
	}
	
	# Get default values
	if(defined($default_class_id))
	{
		my $is_default = 0;
		if($default_class_id == $classID) { $is_default = 1; }
		$json_str .= get_default_json_str($dbh,"tab_panel_classes","classID",$default_class_id,$is_default);
	}		
	
	if($classID != 0)
	{
		
	foreach my $table (@normal_tables_by_classID)
	{
		$sql_str="select * from ".$table." where classID=".$classID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		my $ary_ref = $sth->fetchrow_arrayref;
		my $i = 0;
		$json_str .= "{type:'normal',id:'".$table."-id"."',value:'".$classID."'},";
		if(exists $ary_ref->[$i])
		{
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				if($sth->{NAME}->[$i] ne "bgListType" && $sth->{NAME}->[$i] ne "groupListType" && $sth->{NAME}->[$i] ne "userListType")
				{
					$json_str .= "{type:'normal',id:'".$table."-".$sth->{NAME}->[$i]."',value:'".$ary_ref->[$i]."'},";
				}
				else
				{
					$json_str .= "{type:'radio',id:'".$table."-".$sth->{NAME}->[$i]."',value:'".$ary_ref->[$i]."'},";
				}
			}
		}
	}

	foreach my $table (@editable_tables_by_classID)
	{
		$sql_str="select * from ".$table." where classID=".$classID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		$json_str .= "{type:'editable',table_name:'".$table."',key_id:'".$classID."',rows:[";
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
			$json_str .= "{columns:[";
			my $i;
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				$json_str .= "{col_name:'".$sth->{NAME}->[$i]."',col_value:'".$ary_ref->[$i]."',col_title:'".$sth->{NAME}->[$i]."'},";
			}
			$json_str =~ s/,$//g;
			$json_str .= "]},";
		}
		$json_str =~ s/,$//g;
		$json_str .= "]},";
	}	
	
	foreach my $table (@multi_select_tables_by_classID)
	{
		$sql_str="select * from ".$table." where classID=".$classID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		$json_str .= "{type:'multisel',table_name:'".$table."',key_id:'".$classID."',values:[";
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
		    $json_str .= "{a:'".$ary_ref->[1]."'},";
		}
		$json_str =~ s/,$//g;
		$json_str .= "]},";		
	}

	} # classID != 0
	
	$json_str =~ s/,$//g;
	$json_str .= "]";
	if(defined($sth)) {$sth->finish();}
	print $json_str;
	$dbh->disconnect();

}

==> LL_utils-5.1.0.17-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/pull_down_tab_panel_classes.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)22 1.12 src/ll/config_editor/cgi-bin/pull_down_tab_panel_classes.pl, ll.config, ll_rrnep2, rrnep21206a 10/2/10 18:13:33\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(0);

my @normal_tables_by_classID = @{LLUtil::ALL_TABLES->{"tab_panel_classes"}->[0]};
my @editable_tables_by_classID = @{LLUtil::ALL_TABLES->{"tab_panel_classes"}->[1]};
my @multi_select_tables_by_classID = @{LLUtil::ALL_TABLES->{"tab_panel_classes"}->[2]};

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;
if(/id=(\d+)&name=(.*)&cluster=(\d+)/)
{
	my $json_str_0 = "Content-type: text/html\n\n";
	
	my $dbh = get_dbh(0);
        if(!defined($dbh))
	{
		error_and_exit($dbh->errstr);
	}
	
	my $classID = $1;
	my $option_name = $2;
	my $cluster_id = $3;
	
	my $sql_str;
	my $sth;

	my $json_str = $json_str_0."[";

	# Get default class id
	my $default_class_id = undef;
	if($classID != 0)
	{
		$default_class_id = get_default_id_by_primary_key($dbh,"classID","clusterID","TLLS_CFGClass","name",$classID);
	}
	else
	{
		$default_class_id = get_default_id($dbh,"classID","name","TLLS_CFGClass",$cluster_id);
	}
	
	# Get default values
	if(defined($default_class_id))
	{
		my $is_default = 0;
		if($default_class_id == $classID) { $is_default = 1; }
		$json_str .= get_default_json_str($dbh,"tab_panel_classes","classID",$default_class_id,$is_default);
	}		
	
	if($classID != 0)
	{
		
	foreach my $table (@normal_tables_by_classID)
	{
		$sql_str="select * from ".$table." where classID=".$classID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		my $ary_ref = $sth->fetchrow_arrayref;
		my $i = 0;
		$json_str .= "{type:'normal',id:'".$table."-id"."',value:'".$classID."'},";
		if(exists $ary_ref->[$i])
		{
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				my $field = lc($sth->{NAME}->[$i]);
debug_log("assigned field:".$field);
				if($field ne lc("bgListType") && $field ne lc("groupListType") && $field ne lc("userListType"))
				{
debug_log("No match for ".$field);
					$json_str .= "{type:'normal',id:'".$table."-".$sth->{NAME}->[$i]."',value:'".$ary_ref->[$i]."'},";
				}
				else
				{
debug_log("Match for ".$field);
					$json_str .= "{type:'radio',id:'".$table."-".$field."',value:'".$ary_ref->[$i]."'},";
				}
			}
		}
	}

	foreach my $table (@editable_tables_by_classID)
	{
		$sql_str="select * from ".$table." where classID=".$classID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		$json_str .= "{type:'editable',table_name:'".$table."',key_id:'".$classID."',rows:[";
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
			$json_str .= "{columns:[";
			my $i;
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				$json_str .= "{col_name:'".$sth->{NAME}->[$i]."',col_value:'".$ary_ref->[$i]."',col_title:'".$sth->{NAME}->[$i]."'},";
			}
			$json_str =~ s/,$//g;
			$json_str .= "]},";
		}
		$json_str =~ s/,$//g;
		$json_str .= "]},";
	}	
	
	foreach my $table (@multi_select_tables_by_classID)
	{
		$sql_str="select * from ".$table." where classID=".$classID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		$json_str .= "{type:'multisel',table_name:'".$table."',key_id:'".$classID."',values:[";
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
		    $json_str .= "{a:'".$ary_ref->[1]."'},";
		}
		$json_str =~ s/,$//g;
		$json_str .= "]},";		
	}

	} # classID != 0
	
	$json_str =~ s/,$//g;
	$json_str .= "]";
	if(defined($sth)) {$sth->finish();}
	print $json_str;
	$dbh->disconnect();

}
